import { useState, useEffect } from "react";
import logo from './logo.svg';
import './App.css';

import {Typography, TextField, InputAdornment, Grid, } from "@material-ui/core";
import FavoriteIcon from "@material-ui/icons/Favorite";


const App = (props) => {
    const [values, setValues] = useState({
        total: "",
        skeinLength: "",
        skeinPrice: "",
        skeinCount: "",
    });

    // const [skeinCount, setSkeinCount] = useState("");
    const [totalPrice, setTotalPrice] = useState();
    const [skeinsRequiredDisabled, setSkeinsRequiredDisabled] = useState(false);

    const _handleChange = (event) => {
        const { id, value } = event.target;

        // console.log("changing", id, value);

        setValues({
            ...values,
            [id]: parseFloat(value || 0),
        });

    };

    useEffect(() => {
        const newSkeinCount = Math.ceil((Number(values.total) / Number(values.skeinLength || 0)) || 0);
        const newTotal = Number(newSkeinCount * Number(values.skeinPrice) || 0).toFixed(2);

        // console.log(newSkeinCount, newTotal);

        if (!values.total && !values.skeinLength) {
            // console.log("setting a basic total");
            setSkeinsRequiredDisabled(false);
            // setValues({ ...values, skeinCount: newSkeinCount });
            setTotalPrice((Number(values.skeinCount) || 0) * (Number(values.skeinPrice) || 0));
        } else {
            // console.log("setting a complicated total");
            if (newSkeinCount !== values.skeinCount) setValues({
                ...values,
                skeinCount: newSkeinCount,
            });

            setSkeinsRequiredDisabled(true);
            setTotalPrice(newTotal);
        }

        // console.log("change", values);
    }, [values]);

    return (
        <div className="App">
            <Grid container direction="column" spacing={2}>
                <Grid item xs={12}>
                    <Typography variant="h1" gutterBottom>yarn calc <FavoriteIcon style={{ fontSize: "inherit", color: "#cc0000", position: "relative", top: "12px" }}/></Typography>
                    <Typography variant="h6">Project details</Typography>
                    <TextField
                        label="Total yardage"
                        id="total"
                        value={values.total}
                        onChange={_handleChange}
                        type="number"
                        variant="outlined"
                        InputProps={{
                            endAdornment: <InputAdornment position="end">yards</InputAdornment>,
                        }}
                        fullWidth
                    />
                </Grid>
                <Grid item xs={12}>
                    <Typography variant="h6">Yarn details</Typography>
                    <TextField
                        label="Yardage per skein"
                        id="skeinLength"
                        value={values.skeinLength}
                        onChange={_handleChange}
                        type="number"
                        variant="outlined"
                        InputProps={{
                            endAdornment: <InputAdornment position="end">yards</InputAdornment>,
                        }}
                        fullWidth
                    />
                </Grid>
                <Grid item xs={12}>
                    <TextField
                        label="Price per skein"
                        id="skeinPrice"
                        value={values.skeinPrice}
                        onChange={_handleChange}
                        type="number"
                        variant="outlined"
                        fullWidth
                        InputProps={{
                            startAdornment: <InputAdornment position="start">$</InputAdornment>,
                        }}
                    />
                </Grid>
                <Grid item xs={12}>
                    <TextField
                        label="Number of skeins required"
                        id="skeinCount"
                        type={skeinsRequiredDisabled ? null : "number"}
                        onChange={_handleChange}
                        value={values.skeinCount}
                        fullWidth
                        inputProps={{ readOnly: skeinsRequiredDisabled }}
                    />
                </Grid>
                <Grid item xs={12}>
                    <Typography variant="h6">Total project cost</Typography>
                    <TextField
                        id="totalPrice"
                        value={totalPrice}
                        fullWidth
                        InputProps={{
                            readOnly: true,
                            startAdornment: <InputAdornment position="start">$</InputAdornment>,
                            style: { fontSize: "36px" },
                        }}
                    />
                </Grid>
                <Grid item xs={12}>
                    <Typography component="small">(ps love you)</Typography>
                </Grid>

            </Grid>
        </div>
    );
};

export default App;
